@@ -149,14 +149,7 @@ def verify_remove_route(route):
 
 
 def options_command(argument):
-    parser = argparse.ArgumentParser(description='FastApi Multitenant.')
-    parser.add_argument("--route", help="Crete new route.")
-    parser.add_argument("--r", help="Crete new route.")
-    parser.add_argument("--remove-route", help="Remove route.")
-    parser.add_argument("--rm-r", help="Remove route.")
-    parser.add_argument("--migrate", help="Migarte.", nargs='?', const=1, type=int)
-    parser.add_argument("--makemigration", help="Migarte.")
-    args = parser.parse_args()
+    args = argument
     print ("2****************")
     print ("****************")
     print ("****************")
@@ -184,11 +177,14 @@ def options_command(argument):
                 migrate()
    
 def main(args=None):
-    print ("1-----------")
-    print ("-----------")
-    print ("-----------")
-    print ("-----------")
-    print(args)
+    parser = argparse.ArgumentParser(description='FastApi Multitenant.')
+    parser.add_argument("--route", help="Crete new route.")
+    parser.add_argument("--r", help="Crete new route.")
+    parser.add_argument("--remove-route", help="Remove route.")
+    parser.add_argument("--rm-r", help="Remove route.")
+    parser.add_argument("--migrate", help="Migarte.", nargs='?', const=1, type=int)
+    parser.add_argument("--makemigration", help="Migarte.")
+    args = parser.parse_args()
     options_command(args)
 
 if __name__ == "__main__":
